@@ -119,8 +119,9 @@ unordered_clauses = [
 
 ordered_clauses = [
     "orderby",
-    "offset",
     "limit",
+    "offset",
+    "fetch",
 ]
 
 
@@ -179,6 +180,8 @@ class Formatter:
                 return "NULL"
             elif "trim" in json:
                 return self._trim(json, prec)
+            elif "extract" in json:
+                return self._extract(json, prec)
             else:
                 return self.op(json, prec)
         if isinstance(json, string_types):
@@ -348,6 +351,13 @@ class Formatter:
 
         return f"CAST({self.dispatch(expr)} AS {self.dispatch(type)})"
 
+    def _extract(self, json, prec):
+        interval, value = json['extract']
+        i = self.dispatch(interval).upper()
+        v = self.dispatch(value)
+        return f"EXTRACT({i} FROM {v})"
+
+
     def _interval(self, json, prec):
         amount = self.dispatch(json[0], precedence["and"])
         type = self.dispatch(json[1], precedence["and"])
@@ -543,12 +553,16 @@ class Formatter:
 
     def limit(self, json, prec):
         num = self.dispatch(json["limit"], precedence["order"])
-        return f"FETCH {num} ROWS ONLY"
+        return f"LIMIT {num}"
 
     def offset(self, json, prec):
         num = self.dispatch(json["offset"], precedence["order"])
         return f"OFFSET {num}"
 
+    def fetch(self, json, prec):
+        num = self.dispatch(json["offset"], precedence["order"])
+        return f"FETCH {num} ROWS ONLY"
+
     def insert(self, json, prec=precedence["from"]):
         acc = ["INSERT"]
         if "overwrite" in json:
